@@ -40,9 +40,14 @@ def simplify_graphml(graphpath, directed=True, simplify=True):
     return g
 
 ##########################################################
-def plot_graph(g, plotpath, shppath=''):
-    """Plot the graph @g and export to @plotpath and, if provided, plot
+def plot_graph(gin, plotpath, shppath=''):
+    """Plot the graph @gin and export to @plotpath and, if provided, plot
     the border given by @shppath"""
+    if type(g) == str:
+        g = simplify_graphml(g, directed=False, simplify=True)
+    else:
+        g = gin
+
     vcoords = np.array([(x, y) for x, y in zip(g.vs['x'], g.vs['y'])])
 
     ecoords = []
